@@ -3,6 +3,7 @@
    if (file_exists('../../../../functions/global.php'))
    {
       define('SM_PATH', '../../../../');
+      include_once(SM_PATH . 'include/constants.php');
       include_once(SM_PATH . 'functions/global.php');
    }
    else exit;
@@ -38,7 +39,7 @@
 //////////////////////////////////////////////////////
 
 if (!@include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config.php'))
-   include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config.sample.php');
+   include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config_default.php');
 
 global $site_tags, $tag_string, $tag_pos, $rand_func, $seed_func,
        $hash_func, $output, $use_dict, $dict_location, $max_word_length,
@@ -102,7 +103,7 @@ if ((isset($sSessionAutostartName) || $sSessionAutostartName == '') &&
     $sCookiePath = ini_get('session.cookie_path');
     $sCookieDomain = ini_get('session.cookie_domain');
     // reset the cookie
-    setcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
+    sqsetcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
     @session_destroy();
     session_write_close();
 }
