@@ -38,7 +38,7 @@
 //////////////////////////////////////////////////////
 
 if (!@include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config.php'))
-   include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config.sample.php');
+   include_once(SM_PATH . 'plugins/captcha/backends/freecap/freecap_config_default.php');
 
 global $site_tags, $tag_string, $tag_pos, $rand_func, $seed_func,
        $hash_func, $output, $use_dict, $dict_location, $max_word_length,
