@@ -44,7 +44,35 @@ function recaptcha_show_input_widgets()
 {
 
    global $is_secure_connection, $recaptcha_theme, 
-          $recaptcha_public_key, $recaptcha_tabindex;
+          $recaptcha_public_key, $recaptcha_tabindex,
+          $squirrelmail_language;
+
+
+   // reCAPTCHA only has a limited set of translations
+   // available by default (TODO: we could solicit other
+   // translations or probably find them already done on
+   // the web and add those as custom translations using
+   // the info here:
+   // https://code.google.com/apis/recaptcha/docs/customization.html
+   // but for now, we limit to the ones supplied by reCAPTCHA)
+   //
+   $recaptcha_translations = array(
+      'en_US' => 'en',
+      'en_GB' => 'en',
+      'nl_NL' => 'nl',
+      'fr_FR' => 'fr',
+      'de_DE' => 'de',
+      'pt_BR' => 'pt',
+      'pt_PT' => 'pt',
+      'ru_RU' => 'ru',
+      'ru_UA' => 'ru',
+      'es_ES' => 'es',
+      'tr_TR' => 'tr',
+   );
+   if (!empty($recaptcha_translations[$squirrelmail_language]))
+      $recaptcha_lang = $recaptcha_translations[$squirrelmail_language];
+   else
+      $recaptcha_lang = '';
 
 
    // determine if this is a secure connection... I suppose
@@ -118,6 +146,9 @@ function recaptcha_show_input_widgets()
          $output .="<script language=\"JavaScript\" type=\"text/javascript\">\n"
                  . "<!--\n"
                  . "   var RecaptchaOptions = {\n"
+                 . (!empty($recaptcha_lang) ? "      lang : '" . $recaptcha_lang
+                                             . (!empty($recaptcha_theme) || !empty($recaptcha_tabindex) ? "',\n" : "'\n")
+                                             : '')
                  . (!empty($recaptcha_theme) ? "      theme : '" . $recaptcha_theme 
                                              . (!empty($recaptcha_tabindex) ? "',\n" : "'\n")
                                              : '')
@@ -160,6 +191,9 @@ function recaptcha_show_input_widgets()
       $output .="<script language=\"JavaScript\" type=\"text/javascript\">\n"
               . "<!--\n"
               . "   var RecaptchaOptions = {\n"
+              . (!empty($recaptcha_lang) ? "      lang : '" . $recaptcha_lang
+                                          . (!empty($recaptcha_theme) || !empty($recaptcha_tabindex) ? "',\n" : "'\n")
+                                          : '')
               . (!empty($recaptcha_theme) ? "      theme : '" . $recaptcha_theme
                                           . (!empty($recaptcha_tabindex) ? "',\n" : "'\n")
                                           : '')
@@ -224,8 +258,17 @@ function recaptcha_validate_captcha()
       return NULL;
 
 
-   global $recaptcha_private_key;
-   $recapcha_verify_host = 'api-verify.recaptcha.net';
+   global $recaptcha_private_key, $recaptcha_verify_proxy_port,
+          $recaptcha_verify_proxy_host;
+   $verify_uri = '/recaptcha/api/verify';
+   $recapcha_verify_host = 'www.google.com';
+   if (empty($recaptcha_verify_proxy_host))
+      $recaptcha_verify_proxy_host = $recapcha_verify_host;
+   else
+      // would some proxy servers allow using https here?  older Squid does not
+      $verify_uri = 'http://' . $recapcha_verify_host . $verify_uri;
+   if (empty($recaptcha_verify_proxy_port))
+      $recaptcha_verify_proxy_port = 80;
 
 
    // set up POST payload
@@ -238,7 +281,7 @@ function recaptcha_validate_captcha()
 
    // ask reCAPTCHA server if response was correct
    //
-   $verify_request = "POST /verify HTTP/1.0\r\n"
+   $verify_request = "POST $verify_uri HTTP/1.0\r\n"
                    . "Host: $recapcha_verify_host\r\n"
                    . "User-Agent: SquirrelMail CAPTCHA Plugin\r\n"
                    . "Content-Type: application/x-www-form-urlencoded\r\n"
@@ -247,7 +290,8 @@ function recaptcha_validate_captcha()
                    . "\r\n" . $payload;
 
 
-   if (!($SOCKET = @fsockopen($recapcha_verify_host, 80, $errno, $errstr, 30)))
+   if (!($SOCKET = @fsockopen($recaptcha_verify_proxy_host,
+                              $recaptcha_verify_proxy_port, $errno, $errstr, 30)))
    {
       // TODO: indicate to user that the error was a connection problem?
       //
