@@ -12,7 +12,8 @@
 
 
    global $recaptcha_public_key, $recaptcha_private_key,
-          $recaptcha_tabindex, $recaptcha_theme; 
+          $recaptcha_tabindex, $recaptcha_theme,
+          $recaptcha_verify_proxy_host, $recaptcha_verify_proxy_port;
 
 
 
@@ -29,12 +30,12 @@
    // This is the desired theme that will be provided by reCAPTCHA
    // See http://recaptcha.net/apidocs/captcha/
    //
-   // Current acceptable values are "red", "white", and "blackglass"
+   // Current acceptable values are "clean", "red", "white", and "blackglass"
    //   
    // Note that this value is liable to be overridden in SquirrelMail
    // 1.5.2+ by a skin if it so desires
    //
-   $recaptcha_theme = 'blackglass';
+   $recaptcha_theme = 'white';
 
 
 
@@ -47,3 +48,14 @@
 
 
 
+   // If your system resides behind a proxy, the connection that is
+   // made from SquirrelMail directly to the reCAPTCHA server to
+   // verify user input may need to be routed through your proxy.
+   // If this is the case, you need to specify the proxy's host name
+   // and port below.
+   //
+   $recaptcha_verify_proxy_host = '';
+   $recaptcha_verify_proxy_port = 0;
+
+
+
